Vsew

Enum Vsew 

#[repr(u8)]
pub enum Vsew { E8 = 8, E16 = 16, E32 = 32, E64 = 64, }
Selected element width (SEW).

Encoded in vtype[5:3] as vsew. SEW = 8 * 2^vsew.

Variants



E8 = 8

SEW = 8 bits (vsew = 0b000)



E16 = 16

SEW = 16 bits (vsew = 0b001)



E32 = 32

SEW = 32 bits (vsew = 0b010)



E64 = 64

SEW = 64 bits (vsew = 0b011)

Implementations

Source

impl Vsew

pub const fn from_bits(bits: u8) -> Option<Self>

Decode from the 3-bit vsew field. Returns None for reserved encodings.

pub const fn to_bits(self) -> u8

Encode to the 3-bit vsew field

pub const fn double_width(self) -> Option<Self>

Get the double element width, if available

pub const fn divide_by_factor(self, factor: VsewFactor) -> Option<Self>

Divide Vsew width by a given factor

pub const fn bits_width(self) -> u8

Element width in bits

pub const fn bytes_width(self) -> u8

Element width in bytes

pub const fn as_eew(self) -> Eew

Convert to the corresponding Eew variant.

Every valid Vsew value has a directly corresponding Eew value because both enumerate the same set of widths (8/16/32/64 bits). The conversion is always successful.