#[repr(u8)]pub enum VRegGroupSize {
R1 = 1,
R2 = 2,
R4 = 4,
R8 = 8,
}Expand description
Number of vector registers in a register group.
Register groups always consist of a power of two number of registers, whether from
LMUL, EMUL of a memory operand or a whole-register move.
Variants
Implementations
Sourceimpl VRegGroupSize
impl VRegGroupSize
Sourcepub const fn divide_by_factor(self, factor: VsewFactor) -> Self
pub const fn divide_by_factor(self, factor: VsewFactor) -> Self
Size of a group with factor times fewer registers, at least one.
This is the source group of a vzext/vsext, whose EMUL = LMUL / factor.