#[repr(u8)]pub enum VsStatus {
Off = 0,
Initial = 1,
Clean = 2,
Dirty = 3,
}Expand description
mstatus.VS / sstatus.VS / vsstatus.VS field encoding.
Context status for the vector extension, analogous to mstatus.FS.
Located at bits [10:9] in the respective status registers.
Variants
Off = 0
Vector unit is off; any vector instruction or CSR access raises illegal instruction
Initial = 1
Vector state is known to be in its initial state
Clean = 2
Vector state is potentially modified but matches the last saved state
Dirty = 3
Vector state has been modified since the last save
Implementations